@@ -6,9 +6,11 @@ EXTENSIONS = {
     'avif': {'binary', 'image', 'avif'},
     'bash': {'text', 'shell', 'bash'},
     'bat': {'text', 'batch'},
+    'bats': {'text', 'shell', 'bash', 'bats'},
     'bib': {'text', 'bib'},
     'bmp': {'binary', 'image', 'bitmap'},
     'bz2': {'binary', 'bzip2'},
+    'bzl': {'text', 'bazel'},
     'c': {'text', 'c'},
     'cc': {'text', 'c++'},
     'cfg': {'text'},
@@ -181,11 +183,13 @@ EXTENSIONS = {
     'tiff': {'binary', 'image', 'tiff'},
     'toml': {'text', 'toml'},
     'ts': {'text', 'ts'},
+    'tsv': {'text', 'tsv'},
     'tsx': {'text', 'tsx'},
     'ttf': {'binary', 'ttf'},
     'twig': {'text', 'twig'},
     'txsprofile': {'text', 'ini', 'txsprofile'},
     'txt': {'text', 'plain-text'},
+    'urdf': {'text', 'xml', 'urdf'},
     'v': {'text', 'verilog'},
     'vb': {'text', 'vb'},
     'vbproj': {'text', 'xml', 'vbproj'},
@@ -217,8 +221,10 @@ EXTENSIONS = {
     'yang': {'text', 'yang'},
     'yin': {'text', 'xml', 'yin'},
     'yml': {'text', 'yaml'},
+    'zcml': {'text', 'xml', 'zcml'},
     'zig': {'text', 'zig'},
     'zip': {'binary', 'zip'},
+    'zpt': {'text', 'zpt'},
     'zsh': {'text', 'shell', 'zsh'},
 }
 EXTENSIONS_NEED_BINARY_CHECK = {
@@ -262,8 +268,8 @@ NAMES = {
     '.zshrc': EXTENSIONS['zsh'],
     '.zshenv': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
-    'BUILD': {'text', 'bazel'},
-    'BUILD.bazel': {'text', 'bazel'},
+    'BUILD': EXTENSIONS['bzl'],
+    'BUILD.bazel': EXTENSIONS['bzl'],
     'CMakeLists.txt': EXTENSIONS['cmake'],
     'CHANGELOG': EXTENSIONS['txt'],
     'CONTRIBUTING': EXTENSIONS['txt'],
@@ -287,4 +293,6 @@ NAMES = {
     'README': EXTENSIONS['txt'],
     'Rakefile': EXTENSIONS['rb'],
     'setup.cfg': EXTENSIONS['ini'],
+    'WORKSPACE': EXTENSIONS['bzl'],
+    'wscript': EXTENSIONS['py'],
 }
